@@ -54,7 +54,7 @@ def from_config(config):
 def get_distargs(dist):
     ''' Get dictionary of arguments defining this Distribution instance. '''
     try:
-        return dist.get_distargs()  # Instance of Distribution class
+        return dist.get_distargs().copy()  # Instance of Distribution class
     except AttributeError:
         # stats.rv_ class
         kwds = dist.kwds.copy()
@@ -377,10 +377,10 @@ class DPoisson(Distribution):
         ''' Update the keywords for the distribution. '''
         self.kwds.update(kwds)
         v = self.kwds.get('v', 1)
-        self.distargs = {'loc': v, 'mu': v}
+        self.distargs = {'loc': -v, 'mu': v}  # Since Median value will be applied later, shift loc to -v to compensate.
 
     def helpstr(self):
-        return 'Poisson discrete distribution with variance v. In general, mean should equal variance.'
+        return 'Poisson discrete distribution with variance v. In general, measured value should equal variance.'
 
 
 class DBinom(Distribution):
