@@ -912,7 +912,7 @@ class InputFunc(object):
         gidegf = [x**4/i for x, i in zip(gradu, idegf)]
         gidegf = [g for g in gidegf if np.isfinite(g)]
         try:
-            self._degf = (uncert**4 / sum(gidegf)).magnitude   # numpy: uncert**4 / np.nansum(gradu**4 / idegf)
+            self._degf = (uncert**4 / sum(gidegf)).to_reduced_units().magnitude   # numpy: uncert**4 / np.nansum(gradu**4 / idegf)
         except AttributeError:
             self._degf = np.inf
 
@@ -995,8 +995,8 @@ class InputFunc(object):
                     # Call might have failed if basefunc is not vectorizable. Use numpy vectorize
                     # to broadcast over array and try again.
                     ustd = uparser.callf(np.vectorize(basefunc), x).std()
-                sens.append((ustd/v.stdunc()).to_reduced_units())   # to_reduced_units() will take care of prefix multipliers and dimensionless values
-                props.append((ustd/stdY).to_reduced_units().magnitude**2 * 100)
+                sens.append((ustd/v.stdunc()).to_base_units().to_reduced_units())   # to_reduced_units() will take care of prefix multipliers and dimensionless values
+                props.append((ustd/stdY).to_base_units().to_reduced_units().magnitude**2 * 100)
 
         params = {'mean': meanY,
                   'expected': self.mean(),   # expected/measured value may not match mean or median of MC distribution
@@ -1914,7 +1914,7 @@ class UncertCalc(object):
 
         try:
             config = yaml.safe_load(yml)
-        except yaml.scanner.ScannerError:
+        except yaml.YAMLError:
             return None  # Can't read YAML
 
         if isinstance(config, list):
